@@ -5,7 +5,6 @@ from __future__ import unicode_literals
 import re
 import random as random_module
 
-
 _re_token = re.compile(r'\{\{(\s?)(\w+)(\s?)\}\}')
 random = random_module.Random()
 mod_random = random  # compat with name released in 0.8
@@ -23,7 +22,7 @@ class Generator(object):
 
     def add_provider(self, provider):
 
-        if type(provider) is type:
+        if isinstance(provider, type):
             provider = provider(self)
 
         self.providers.insert(0, provider)
@@ -35,8 +34,7 @@ class Generator(object):
 
             faker_function = getattr(provider, method_name)
 
-            if hasattr(faker_function, '__call__') or \
-                    isinstance(faker_function, (classmethod, staticmethod)):
+            if callable(faker_function):
                 # add all faker method to generator
                 self.set_formatter(method_name, faker_function)
 
@@ -56,12 +54,18 @@ class Generator(object):
     def random(self):
         return self.__random
 
+    @random.setter
+    def random(self, value):
+        self.__random = value
+
     def seed_instance(self, seed=None):
         """Calls random.seed"""
         if self.__random == random:
-            # create per-instance random obj when first time seed_instance() is called
+            # create per-instance random obj when first time seed_instance() is
+            # called
             self.__random = random_module.Random()
         self.__random.seed(seed)
+        return self
 
     @classmethod
     def seed(cls, seed=None):
@@ -80,11 +84,11 @@ class Generator(object):
         except AttributeError:
             if 'locale' in self.__config:
                 msg = 'Unknown formatter "{0}" with locale "{1}"'.format(
-                    formatter, self.__config['locale']
+                    formatter, self.__config['locale'],
                 )
             else:
                 raise AttributeError('Unknown formatter "{0}"'.format(
-                    formatter
+                    formatter,
                 ))
             raise AttributeError(msg)
 
