@@ -12,5 +12,5 @@ class Provider(PhoneNumberProvider):
         '(###)### ####',
         '### # ###',
         '+90(###)###-####x###',
-        '+90(###)###-####x####'
+        '+90(###)###-####x####',
     )
