@@ -5,18 +5,11 @@ from __future__ import unicode_literals
 from decimal import Decimal
 import sys
 
+import six
+
 from .. import BaseProvider
 
 
-if sys.version_info[0] == 2:
-    string_types = (basestring,)
-elif sys.version_info[0] == 3:
-    string_types = (str, bytes)
-else:
-    raise SystemError(
-        "Unrecognized python version: {}".format(sys.version_info[0]))
-
-
 class Provider(BaseProvider):
     def pybool(self):
         return self.random_int(0, 1) == 1
@@ -36,10 +29,12 @@ class Provider(BaseProvider):
             return "".join(
                 self.random_letters(
                     length=self.generator.random.randint(min_chars, max_chars),
-                )
+                ),
             )
 
-    def pyfloat(self, left_digits=None, right_digits=None, positive=False):
+    def pyfloat(self, left_digits=None, right_digits=None, positive=False,
+                min_value=None, max_value=None):
+
         if left_digits is not None and left_digits < 0:
             raise ValueError(
                 'A float number cannot have less than 0 digits in its '
@@ -51,23 +46,40 @@ class Provider(BaseProvider):
         if left_digits == 0 and right_digits == 0:
             raise ValueError(
                 'A float number cannot have less than 0 digits in total')
+        if None not in (min_value, max_value) and min_value > max_value:
+            raise ValueError('Min value cannot be greater than max value')
 
         left_digits = left_digits if left_digits is not None else (
             self.random_int(1, sys.float_info.dig))
         right_digits = right_digits if right_digits is not None else (
             self.random_int(0, sys.float_info.dig - left_digits))
-        sign = 1 if positive else self.random_element((-1, 1))
+        sign = ''
+        if (min_value is not None) or (max_value is not None):
+            if min_value is None:
+                min_value = max_value - self.random_int()
+            if max_value is None:
+                max_value = min_value + self.random_int()
 
-        return float("{0}.{1}".format(
-            sign * self.random_number(left_digits),
-            self.random_number(right_digits)
+            left_number = self.random_int(min_value, max_value)
+        else:
+            sign = '+' if positive else self.random_element(('+', '-'))
+            left_number = self.random_number(left_digits)
+
+        return float("{0}{1}.{2}".format(
+            sign,
+            left_number,
+            self.random_number(right_digits),
         ))
 
-    def pyint(self):
-        return self.generator.random_int()
+    def pyint(self, min=0, max=9999, step=1):
+        return self.generator.random_int(min, max, step=step)
 
-    def pydecimal(self, left_digits=None, right_digits=None, positive=False):
-        return Decimal(str(self.pyfloat(left_digits, right_digits, positive)))
+    def pydecimal(self, left_digits=None, right_digits=None, positive=False,
+                  min_value=None, max_value=None):
+
+        float_ = self.pyfloat(
+            left_digits, right_digits, positive, min_value, max_value)
+        return Decimal(str(float_))
 
     def pytuple(self, nb_elements=10, variable_nb_elements=True, *value_types):
         return tuple(
@@ -113,7 +125,7 @@ class Provider(BaseProvider):
             variable_nb_elements=True,
             *value_types):
 
-        value_types = [t if isinstance(t, string_types) else getattr(t, '__name__', type(t).__name__).lower()
+        value_types = [t if isinstance(t, six.string_types) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t not in ['iterable', 'list', 'tuple', 'dict', 'set']]
@@ -140,12 +152,12 @@ class Provider(BaseProvider):
 
         return dict(zip(
             self.generator.words(nb_elements),
-            self._pyiterable(nb_elements, False, *value_types)
+            self._pyiterable(nb_elements, False, *value_types),
         ))
 
     def pystruct(self, count=10, *value_types):
 
-        value_types = [t if isinstance(t, string_types) else getattr(t, '__name__', type(t).__name__).lower()
+        value_types = [t if isinstance(t, six.string_types) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t != 'struct']
@@ -153,12 +165,12 @@ class Provider(BaseProvider):
             value_types = ['str', 'str', 'str', 'str', 'float',
                            'int', 'int', 'decimal', 'date_time', 'uri', 'email']
 
-        l = []
+        types = []
         d = {}
         nd = {}
         for i in range(count):
             d[self.generator.word()] = self._random_type(value_types)
-            l.append(self._random_type(value_types))
+            types.append(self._random_type(value_types))
             nd[self.generator.word()] = {i: self._random_type(value_types),
                                          i + 1: [self._random_type(value_types),
                                                  self._random_type(value_types),
@@ -167,4 +179,4 @@ class Provider(BaseProvider):
                                                  i + 1: self._random_type(value_types),
                                                  i + 2: [self._random_type(value_types),
                                                          self._random_type(value_types)]}}
-        return l, d, nd
+        return types, d, nd
